@@ -8,7 +8,11 @@ from typer import Exit, Option, Typer, echo
 from rsort import __version__
 from rsort.requirements import Requirements
 
-app = Typer(invoke_without_command=True, help="Sort requirements with ease!")
+app = Typer(
+    invoke_without_command=True,
+    help="Sort requirements with ease!",
+    add_completion=False,
+)
 
 
 def version_callback(value: bool):
@@ -19,10 +23,16 @@ def version_callback(value: bool):
 
 @app.callback()
 def sort(
-    files: Optional[List[str]] = Option(None, help="Requirements file to be sorted"),
-    check: bool = Option(False, "--check", help="Only check if needs to be sorted"),
-    diff: bool = Option(False, "--diff", help="Only changes to be made"),
-    version: bool = Option(None, "--version", callback=version_callback, is_eager=True),
+    files: Optional[List[str]] = Option(None, help="Requirements file to be sorted."),
+    check: bool = Option(False, "--check", help="Only check if needs to be sorted."),
+    diff: bool = Option(False, "--diff", help="Only changes to be made."),
+    version: bool = Option(
+        None,
+        "--version",
+        callback=version_callback,
+        is_eager=True,
+        help="Show rsort version.",
+    ),
 ):
     files = files or ["requirements.txt", "pyproject.toml"]
     need_format = []
